Struct SyncStreamReadHalf
pub struct SyncStreamReadHalf<S> { /* private fields */ }Available on crate features
io and compat only.Expand description
Read half of a SyncStream after splitting.
Implementations
impl<S> SyncStreamReadHalf<S>
impl<S> SyncStreamReadHalf<S>
pub fn into_inner(self) -> S
pub fn into_inner(self) -> S
Consumes the SyncStreamReadHalf, returning the underlying stream.
pub fn into_parts(self) -> (S, Vec<u8>)
pub fn into_parts(self) -> (S, Vec<u8>)
Consumes the SyncStream, returning the underlying stream and any
unread buffered data.
If the read buffer is currently lent to an IO operation, the returned
Vec will be empty.
pub fn read_buf_uninit(
&mut self,
buf: &mut [MaybeUninit<u8>],
) -> Result<usize, Error>
pub fn read_buf_uninit( &mut self, buf: &mut [MaybeUninit<u8>], ) -> Result<usize, Error>
Pull some bytes from this source into the specified buffer.
impl<S> SyncStreamReadHalf<S>where
S: AsyncRead,
impl<S> SyncStreamReadHalf<S>where
S: AsyncRead,
pub async fn fill_read_buf(&mut self) -> Result<usize, Error>
pub async fn fill_read_buf(&mut self) -> Result<usize, Error>